==> jc-1.4.0.tar.gz: javax/swing/JMenu__24WinListener.h <==
// public class javax.swing.JMenu$WinListener

// class file dependencies
// @dep_class e1cb933811e6d542 java_awt_event_WindowAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 287d075911d8f50c javax_swing_JMenu__24WinListener

// header file dependencies
// @dep_header java_awt_event_WindowAdapter

#include "java/awt/event/WindowAdapter.h"

#ifndef _JC_javax_swing_JMenu__24WinListener_H_
#define _JC_javax_swing_JMenu__24WinListener_H_

// Forward structure declarations
struct _jc_java_awt_event_WindowEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JMenu$object;
struct _jc_javax_swing_JPopupMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JMenu__24WinListener$sub_refs	_jc_javax_swing_JMenu__24WinListener$sub_refs;
typedef struct _jc_javax_swing_JMenu__24WinListener$sub_nonrefs	_jc_javax_swing_JMenu__24WinListener$sub_nonrefs;
typedef struct _jc_javax_swing_JMenu__24WinListener$refs	_jc_javax_swing_JMenu__24WinListener$refs;
typedef struct _jc_javax_swing_JMenu__24WinListener$nonrefs	_jc_javax_swing_JMenu__24WinListener$nonrefs;
typedef struct _jc_javax_swing_JMenu__24WinListener$object	_jc_javax_swing_JMenu__24WinListener$object;

typedef struct _jc_javax_swing_JMenu__24WinListener$fields_struct	_jc_javax_swing_JMenu__24WinListener$fields_struct;
typedef const struct _jc_javax_swing_JMenu__24WinListener$vmethods	_jc_javax_swing_JMenu__24WinListener$vmethods;
typedef const struct _jc_javax_swing_JMenu__24WinListener$vtable	_jc_javax_swing_JMenu__24WinListener$vtable;
typedef const struct _jc_javax_swing_JMenu__24WinListener$vtype	_jc_javax_swing_JMenu__24WinListener$vtype;

// Class fields structure
struct _jc_javax_swing_JMenu__24WinListener$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JMenu__24WinListener$fields_struct _jc_javax_swing_JMenu__24WinListener$class_fields;

// Constructors
extern void _jc_javax_swing_JMenu__24WinListener$method$_init$50461180f6ea037a(_jc_env *, struct _jc_javax_swing_JMenu__24WinListener$object *, struct _jc_javax_swing_JMenu$object *, struct _jc_javax_swing_JPopupMenu$object *);

// Virtual methods
extern void _jc_javax_swing_JMenu__24WinListener$method$windowClosing$023e7b882fa85143(_jc_env *, struct _jc_javax_swing_JMenu__24WinListener$object *, struct _jc_java_awt_event_WindowEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JMenu__24WinListener$method_info$windowClosing$023e7b882fa85143;

// Virtual methods structure
struct _jc_javax_swing_JMenu__24WinListener$vmethods {
	void	(*windowClosing$023e7b882fa85143)(_jc_env *, struct _jc_javax_swing_JMenu__24WinListener$object *, struct _jc_java_awt_event_WindowEvent$object *);
};

// Vtable
struct _jc_javax_swing_JMenu__24WinListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_WindowAdapter$vmethods	java_awt_event_WindowAdapter;
	_jc_javax_swing_JMenu__24WinListener$vmethods	javax_swing_JMenu__24WinListener;
};

// Vtype
struct _jc_javax_swing_JMenu__24WinListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JMenu__24WinListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JMenu__24WinListener$sub_refs {
	struct _jc_javax_swing_JPopupMenu$object	*popupMenu;
	struct _jc_javax_swing_JMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JMenu__24WinListener$refs {
    _jc_javax_swing_JMenu__24WinListener$sub_refs	javax_swing_JMenu__24WinListener;
    _jc_java_awt_event_WindowAdapter$sub_refs	java_awt_event_WindowAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JMenu__24WinListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JMenu__24WinListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_WindowAdapter$sub_nonrefs	java_awt_event_WindowAdapter;
    _jc_javax_swing_JMenu__24WinListener$sub_nonrefs	javax_swing_JMenu__24WinListener;
};

// Object instance structure
struct _jc_javax_swing_JMenu__24WinListener$object {
	_jc_javax_swing_JMenu__24WinListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JMenu__24WinListener$vtype	*vtype;
	_jc_javax_swing_JMenu__24WinListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JMenu__24WinListener$vtype _jc_javax_swing_JMenu__24WinListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JMenu__24WinListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JMenu__24WinListener$class_object;

#endif	/* _JC_javax_swing_JMenu__24WinListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JMenu__24WinListener.h <==
// public class javax.swing.JMenu$WinListener

// class file dependencies
// @dep_class e1cb933811e6d542 java_awt_event_WindowAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3a0982299efc2beb javax_swing_JMenu__24WinListener

// header file dependencies
// @dep_header java_awt_event_WindowAdapter

#include "java/awt/event/WindowAdapter.h"

#ifndef _JC_javax_swing_JMenu__24WinListener_H_
#define _JC_javax_swing_JMenu__24WinListener_H_

// Forward structure declarations
struct _jc_java_awt_event_WindowEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JMenu$object;
struct _jc_javax_swing_JPopupMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JMenu__24WinListener$sub_refs	_jc_javax_swing_JMenu__24WinListener$sub_refs;
typedef struct _jc_javax_swing_JMenu__24WinListener$sub_nonrefs	_jc_javax_swing_JMenu__24WinListener$sub_nonrefs;
typedef struct _jc_javax_swing_JMenu__24WinListener$refs	_jc_javax_swing_JMenu__24WinListener$refs;
typedef struct _jc_javax_swing_JMenu__24WinListener$nonrefs	_jc_javax_swing_JMenu__24WinListener$nonrefs;
typedef struct _jc_javax_swing_JMenu__24WinListener$object	_jc_javax_swing_JMenu__24WinListener$object;

typedef struct _jc_javax_swing_JMenu__24WinListener$fields_struct	_jc_javax_swing_JMenu__24WinListener$fields_struct;
typedef const struct _jc_javax_swing_JMenu__24WinListener$vmethods	_jc_javax_swing_JMenu__24WinListener$vmethods;
typedef const struct _jc_javax_swing_JMenu__24WinListener$vtable	_jc_javax_swing_JMenu__24WinListener$vtable;
typedef const struct _jc_javax_swing_JMenu__24WinListener$vtype	_jc_javax_swing_JMenu__24WinListener$vtype;

// Class fields structure
struct _jc_javax_swing_JMenu__24WinListener$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JMenu__24WinListener$fields_struct _jc_javax_swing_JMenu__24WinListener$class_fields;

// Constructors
extern void _jc_javax_swing_JMenu__24WinListener$method$_init$50461180f6ea037a(_jc_env *, struct _jc_javax_swing_JMenu__24WinListener$object *, struct _jc_javax_swing_JMenu$object *, struct _jc_javax_swing_JPopupMenu$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JMenu__24WinListener$method$windowClosing$023e7b882fa85143(_jc_env *, struct _jc_javax_swing_JMenu__24WinListener$object *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JMenu__24WinListener$method_info$windowClosing$023e7b882fa85143;

// Virtual methods structure
struct _jc_javax_swing_JMenu__24WinListener$vmethods {
	void	(*windowClosing$023e7b882fa85143)(_jc_env *, struct _jc_javax_swing_JMenu__24WinListener$object *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JMenu__24WinListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_WindowAdapter$vmethods	java_awt_event_WindowAdapter;
	_jc_javax_swing_JMenu__24WinListener$vmethods	javax_swing_JMenu__24WinListener;
};

// Vtype
struct _jc_javax_swing_JMenu__24WinListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JMenu__24WinListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JMenu__24WinListener$sub_refs {
	struct _jc_javax_swing_JPopupMenu$object	*popupMenu;
	struct _jc_javax_swing_JMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JMenu__24WinListener$refs {
    _jc_javax_swing_JMenu__24WinListener$sub_refs	javax_swing_JMenu__24WinListener;
    _jc_java_awt_event_WindowAdapter$sub_refs	java_awt_event_WindowAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JMenu__24WinListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JMenu__24WinListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_WindowAdapter$sub_nonrefs	java_awt_event_WindowAdapter;
    _jc_javax_swing_JMenu__24WinListener$sub_nonrefs	javax_swing_JMenu__24WinListener;
};

// Object instance structure
struct _jc_javax_swing_JMenu__24WinListener$object {
	_jc_javax_swing_JMenu__24WinListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JMenu__24WinListener$vtype	*vtype;
	_jc_javax_swing_JMenu__24WinListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JMenu__24WinListener$vtype _jc_javax_swing_JMenu__24WinListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JMenu__24WinListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JMenu__24WinListener$class_object;

#endif	/* _JC_javax_swing_JMenu__24WinListener_H_ */
